<!--podmd-->
## _genespans_

* genomic mappings of gene coordinats
* initially limited to _GRCh38_ and overall CDS extension
* responds to (start-anchored) text input of HUGO gene symbols using the `geneId`
parameter
* returns a list of matching gene objects (see below under __Response Formats__)

##### Examples

* <https://progenetix.org/services/genespans?geneId=CDKN2>

<!--/podmd-->
